@@ -49,11 +49,29 @@ class Client(object):
         pass
 
 
+    def delete(self,key):
+        tag = randint(1,100000)
+
+        query = Query()
+        query.method = 'delete'
+        query.tag = tag
+        query.key = key
+
+        for push,pull in zip(self.push,self.pull):
+            push.send(query.SerializeToString())
+            response = Response()
+            response.ParseFromString(pull.recv())
+            if response.data and response.tag == tag:
+                print "LOG: Key {} successfully deleted".format(key)
+
     def put(self,key,data):
         """
         Put to the server cluster. It picks one random server and
         sends a put query
         """
+        #Given that the key may be anywhere, delete the key.
+        self.delete(key)
+        
         tag = randint(1,100000)
 
         query = Query()
@@ -101,22 +119,6 @@ class Client(object):
         return responses
 
 
-    def delete(self,key):
-        tag = randint(1,100000)
-
-        query = Query()
-        query.method = 'delete'
-        query.tag = tag
-        query.key = key
-
-        for push,pull in zip(self.push,self.pull):
-            push.send(query.SerializeToString())
-            response = Response()
-            response.ParseFromString(pull.recv())
-            if response.data and response.tag == tag:
-                print "LOG: Key {} successfully deleted".format(key)
-
-
     def keys(self,key_from=None,key_to=None):
         tag = randint(1,100000)
         responses = list()
